@@ -74,12 +74,11 @@ def fido_search_result():
     # No JSOC query
     return Fido.search(
         net_attrs.Time("2012/1/1", "2012/1/2"),
-        net_attrs.Instrument('lyra') | net_attrs.Instrument('eve') |
+        net_attrs.Instrument('lyra') & net_attrs.Level.two | net_attrs.Instrument('eve') |
         net_attrs.Instrument('XRS') | net_attrs.Instrument('noaa-indices') |
         net_attrs.Instrument('noaa-predict') |
         (net_attrs.Instrument('norh') & net_attrs.Wavelength(17*units.GHz)) |
-        (net_attrs.Instrument('rhessi') & net_attrs.Physobs("summary_lightcurve")) |
-        (net_attrs.Instrument('EVE') & net_attrs.Level(0))
+        (net_attrs.Instrument('rhessi') & net_attrs.Physobs("summary_lightcurve"))
     )
 
 
@@ -87,14 +86,16 @@ def fido_search_result():
 def query_result():
     return vso.VSOClient().search(
         net_attrs.Time('20130801T200000', '20130801T200030'),
-        net_attrs.Instrument('PLASTIC'))
+        net_attrs.Instrument('PLASTIC'),
+        response_format="legacy")
 
 
 @pytest.fixture
 def download_qr():
     return vso.VSOClient().search(
         net_attrs.Time('2020-03-29', '2020-03-29'),
-        net_attrs.Instrument('AIA'))
+        net_attrs.Instrument('AIA'),
+        response_format="legacy")
 
 
 @pytest.fixture
@@ -445,7 +446,7 @@ def test_add_already_existing_entry_ignore(database):
 @pytest.mark.remote_data
 def test_add_entry_from_hek_qr(database):
     hek_res = hek.HEKClient().search(
-        hek.attrs.Time('2011/08/09 07:23:56', '2011/08/09 07:24:00'),
+        net_attrs.Time('2011/08/09 07:23:56', '2011/08/09 07:24:00'),
         hek.attrs.EventType('FL'))
     assert len(database) == 0
     database.add_from_hek_query_result(hek_res)
@@ -492,7 +493,7 @@ def test_hek_query_download(monkeypatch, database, tmpdir):
     monkeypatch.setattr(tables, "entries_from_dir", mock_entries_from_dir)
 
     query = hek.HEKClient().search(
-        hek.attrs.Time('2019/03/10 14:40:10', '2019/04/11 16:40:50'),
+        net_attrs.Time('2019/03/10 14:40:10', '2019/04/11 16:40:50'),
         hek.attrs.EventType('FL')
     )
 
@@ -1108,8 +1109,8 @@ def test_split_database(split_function_database, database):
         split_function_database, database, net_attrs.Instrument('EIA'))
 
     observed_source_entries = split_function_database.search(
-        vso.attrs.Provider('xyz'), sortby='id')
-    observed_destination_entries = database.search(vso.attrs.Provider('xyz'))
+        net_attrs.Provider('xyz'), sortby='id')
+    observed_destination_entries = database.search(net_attrs.Provider('xyz'))
 
     assert observed_source_entries == [
         DatabaseEntry(id=1, instrument='RHESSI', provider='xyz'),
