@@ -21,6 +21,11 @@ AIA_171_IMAGE = os.path.join(testpath, 'aia_171_level1.fits')
 SWAP_LEVEL1_IMAGE = os.path.join(testpath, 'SWAP/resampled1_swap.fits')
 
 
+# Some of the tests iamges contain an invalid BLANK keyword; ignore the warning
+# raised by this
+pytestmark = pytest.mark.filterwarnings("ignore:Invalid 'BLANK' keyword in header")
+
+
 @pytest.mark.parametrize(
     'fname, hdus, length',
     [(RHESSI_IMAGE, None, 4),
@@ -112,6 +117,15 @@ def test_warn_nonascii():
     assert 'BAD' not in fits.keys()
 
 
+def test_warn_nan():
+    # Check that a NaN value raises a warning and not an error
+    with pytest.warns(SunpyUserWarning, match='has a NaN value'):
+        fits = header_to_fits({'bad': float('nan'),
+                               'good': 1.0})
+    assert 'GOOD' in fits.keys()
+    assert 'BAD' not in fits.keys()
+
+
 def test_warn_longkey():
     # Check that a key that is too long raises a warning and not an error
     with pytest.warns(SunpyUserWarning, match='The meta key badlongkey is too long'):
