@@ -50,7 +50,7 @@ def make_fitswcs_header(data, coordinate,
     data : `~numpy.ndarray` or `tuple`
         Array data of Map for which a header is required, or the shape of the
         data array (in numpy order, i.e. ``(y_size, x_size)``).
-    coordinate : `~astropy.coordinates.SkyCoord` or `~astropy.coordinates.BaseFrame`
+    coordinate : `~astropy.coordinates.SkyCoord` or `~astropy.coordinates.BaseCoordinateFrame`
         The coordinate of the reference pixel.
     reference_pixel :`~astropy.units.Quantity` of size 2, optional
         Reference pixel along each axis. These are expected to be Cartestian ordered, i.e
@@ -89,6 +89,11 @@ def make_fitswcs_header(data, coordinate,
     `~sunpy.util.MetaDict`
         The header information required for making a `sunpy.map.GenericMap`.
 
+    Notes
+    -----
+    The observer coordinate is taken from the observer property of the ``reference_pixel``
+    argument.
+
     Examples
     --------
     >>> import sunpy.map
@@ -123,10 +128,6 @@ def make_fitswcs_header(data, coordinate,
 
     meta_wcs = _get_wcs_meta(coordinate, projection_code)
 
-    if hasattr(coordinate, "observer") and isinstance(coordinate.observer, frames.BaseCoordinateFrame):
-        meta_observer = get_observer_meta(coordinate.observer, getattr(coordinate, 'rsun', None))
-        meta_wcs.update(meta_observer)
-
     meta_instrument = _get_instrument_meta(instrument, telescope, observatory, wavelength, exposure)
     meta_wcs.update(meta_instrument)
 
