@@ -1,7 +1,6 @@
 """
 Test Composite Map
 """
-import os
 
 import pytest
 
@@ -11,15 +10,9 @@ from sunpy.tests.helpers import figure_test
 
 testpath = sunpy.data.test.rootdir
 
-
-@pytest.fixture
-def aia171_test_map():
-    return sunpy.map.Map(os.path.join(testpath, 'aia_171_level1.fits'))
-
-
-@pytest.fixture
-def hmi_test_map():
-    return sunpy.map.Map(os.path.join(testpath, 'resampled_hmi.fits'))
+# Ignore missing metadata warnings
+pytestmark = [pytest.mark.filterwarnings('ignore:Missing metadata for observer'),
+              pytest.mark.filterwarnings(r'ignore:Unable to treat `\.meta` as a FITS header')]
 
 
 @pytest.fixture
@@ -32,6 +25,11 @@ def test_plot_composite_map(composite_test_map):
     composite_test_map.plot()
 
 
+@figure_test
+def test_peek_composite_map(composite_test_map):
+    composite_test_map.peek()
+
+
 @figure_test
 def test_plot_composite_map_linewidths(composite_test_map):
     composite_test_map.plot(linewidths=4)
