@@ -3,18 +3,24 @@ This module provides a web scraper.
 """
 import os
 import re
-import datetime
+import calendar
 import warnings
+from time import sleep
 from ftplib import FTP
+from datetime import datetime
 from urllib.error import HTTPError
 from urllib.parse import urlsplit
 from urllib.request import urlopen
 
 from bs4 import BeautifulSoup
+from dateutil.relativedelta import relativedelta
 
 import astropy.units as u
 from astropy.time import Time, TimeDelta
 
+from sunpy import log
+from sunpy.extern.parse import parse
+from sunpy.time import TimeRange
 from sunpy.util.exceptions import SunpyUserWarning
 
 __all__ = ['Scraper']
@@ -41,8 +47,8 @@ class Scraper:
 
     regex : `bool`
         Set to `True` if parts of the pattern uses regexp symbols. Be careful that
-        periods `.` matches any character and therefore it's better to escape them.
-        If `regexp` is used, other ``kwargs`` are ignored and string replacement is
+        periods ``.`` matches any character and therefore it's better to escape them.
+        If regexp is used, other ``kwargs`` are ignored and string replacement is
         not possible. Default is `False`.
 
     Attributes
@@ -81,9 +87,9 @@ class Scraper:
         self.domain = "{0.scheme}://{0.netloc}/".format(urlsplit(self.pattern))
         milliseconds = re.search(r'\%e', self.pattern)
         if not milliseconds:
-            self.now = datetime.datetime.now().strftime(self.pattern)
+            self.now = datetime.now().strftime(self.pattern)
         else:
-            now = datetime.datetime.now()
+            now = datetime.now()
             milliseconds_ = int(now.microsecond / 1000.)
             self.now = now.strftime('{start}{milli:03d}{end}'.format(
                 start=self.pattern[0:milliseconds.start()],
@@ -106,24 +112,61 @@ class Scraper:
         Returns
         -------
         `list` of `str`
-            `List` of all the possible directories valid for the time range given.
+            All the possible directories valid for the time range given.
             Notice that these directories may not exist in the archive.
         """
         # find directory structure - without file names
-        directorypattern = os.path.dirname(self.pattern) + '/'
-        # TODO what if there's not slashes?
-        rangedelta = timerange.dt
+        if '/' in self.pattern:
+            directorypattern = '/'.join(self.pattern.split('/')[:-1]) + '/'
         timestep = self._smallerPattern(directorypattern)
         if timestep is None:
             return [directorypattern]
         else:
-            # Number of elements in the time range (including end)
-            n_steps = rangedelta.sec/timestep.sec
-            TotalTimeElements = int(round(n_steps)) + 1
-            directories = [(timerange.start + n * timestep).strftime(directorypattern)
-                           for n in range(TotalTimeElements)]  # TODO if date <= endate
+            directories = []
+            cur = self._date_floor(timerange.start, timestep)
+            end = self._date_floor(timerange.end, timestep) + timestep
+            while cur < end:
+                directories.append(cur.strftime(directorypattern))
+                cur = cur + timestep
+
             return directories
 
+    @staticmethod
+    def _date_floor(date, timestep):
+        """
+        Return the "floor" of the given date and time step.
+
+        Parameters
+        ----------
+        datetime : `datetime.datetime` or `astropy.time.Time`
+            The date to floor
+        timestep : `dateutil.relativedelta.relativedelta`
+            The smallest time step to floor
+        Returns
+        -------
+        `datetime.datetime`
+            The time floored at the given time step
+
+        """
+        date_parts = [int(p) for p in date.strftime('%Y,%m,%d,%H,%M,%S').split(',')]
+        date_parts[-1] = date_parts[-1] % 60
+        date = datetime(*date_parts)
+        orig_time_tup = date.timetuple()
+        time_tup = [orig_time_tup.tm_year, orig_time_tup.tm_mon, orig_time_tup.tm_mday,
+                    orig_time_tup.tm_hour, orig_time_tup.tm_min, orig_time_tup.tm_sec]
+        if timestep == relativedelta(minutes=1):
+            time_tup[-1] = 0
+        elif timestep == relativedelta(hours=1):
+            time_tup[-2:] = [0, 0]
+        elif timestep == relativedelta(days=1):
+            time_tup[-3:] = [0, 0, 0]
+        elif timestep == relativedelta(months=1):
+            time_tup[-4:] = [1, 0, 0, 0]
+        elif timestep == relativedelta(years=1):
+            time_tup[-5:] = [1, 1, 0, 0, 0]
+
+        return datetime(*time_tup)
+
     def _URL_followsPattern(self, url):
         """
         Check whether the url provided follows the pattern.
@@ -240,7 +283,8 @@ class Scraper:
             return self._ftpfileslist(timerange)
         if urlsplit(directories[0]).scheme == "file":
             return self._localfilelist(timerange)
-        for directory in directories:
+        while directories:
+            directory = directories.pop(0)
             try:
                 opn = urlopen(directory)
                 try:
@@ -253,9 +297,7 @@ class Scraper:
                             else:
                                 fullpath = directory + href
                             if self._URL_followsPattern(fullpath):
-                                datehref = self._extractDateURL(fullpath)
-                                if (datehref.to_datetime() >= timerange.start.to_datetime() and
-                                        datehref.to_datetime() <= timerange.end.to_datetime()):
+                                if self._check_timerange(fullpath, timerange):
                                     filesurls.append(fullpath)
                 finally:
                     opn.close()
@@ -263,6 +305,22 @@ class Scraper:
                 # Ignore missing directories (issue #2684).
                 if http_err.code == 404:
                     continue
+                if http_err.code == 429:
+                    # See if the server has told us how long to back off for
+                    retry_after = http_err.hdrs.get('Retry-After', 1)
+                    try:
+                        # Ensure that we can parse the header as an int in sec
+                        retry_after = int(retry_after)
+                    except Exception:
+                        retry_after = 1
+
+                    log.debug(f"Got 429 while scraping {directory}, waiting for {retry_after} seconds before retrying.")
+
+                    sleep(retry_after)
+
+                    # Put this dir back on the queue
+                    directories.insert(0, directory)
+                    continue
                 raise
             except Exception:
                 raise
@@ -278,9 +336,7 @@ class Scraper:
                 for file_i in ftp.nlst():
                     fullpath = directory + file_i
                     if self._URL_followsPattern(fullpath):
-                        datehref = self._extractDateURL(fullpath)
-                        if (datehref >= timerange.start and
-                                datehref <= timerange.end):
+                        if self._check_timerange(fullpath, timerange):
                             filesurls.append(fullpath)
 
         filesurls = [f'ftp://' + "{0.netloc}{0.path}".format(urlsplit(url))
@@ -303,31 +359,136 @@ class Scraper:
             for file_i in os.listdir(directory):
                 fullpath = directory + file_i
                 if self._URL_followsPattern(fullpath):
-                    datehref = self._extractDateURL(fullpath)
-                    if (datehref >= timerange.start and datehref <= timerange.end):
+                    if self._check_timerange(fullpath, timerange):
                         filepaths.append(fullpath)
         filepaths = [prefix + path for path in filepaths]
         self.pattern = pattern
         return filepaths
 
+    def _check_timerange(self, url, timerange):
+        """
+        Checks whether the time extracted from the URL
+        is valid according to the given time range.
+
+        Parameters
+        ----------
+        url: `str`
+            URL of the file.
+        timerange : `~sunpy.time.TimeRange`
+            Time interval for which files were searched.
+
+        Returns
+        -------
+        `bool`
+            `True` if URL's time overlaps the given timerange, else `False`.
+        """
+        if hasattr(self, 'extractor'):
+            exdict = parse(self.extractor, url).named
+            tr = get_timerange_from_exdict(exdict)
+            return (tr.end >= timerange.start and tr.start <= timerange.end)
+        else:
+            datehref = self._extractDateURL(url).to_datetime()
+            return (timerange.start.to_datetime() <= datehref <= timerange.end.to_datetime())
+
     def _smallerPattern(self, directoryPattern):
         """
         Obtain the smaller time step for the given pattern.
         """
         try:
             if "%S" in directoryPattern:
-                return TimeDelta(1*u.second)
+                return relativedelta(seconds=1)
             elif "%M" in directoryPattern:
-                return TimeDelta(1*u.minute)
+                return relativedelta(minutes=1)
             elif any(hour in directoryPattern for hour in ["%H", "%I"]):
-                return TimeDelta(1*u.hour)
+                return relativedelta(hours=1)
             elif any(day in directoryPattern for day in ["%d", "%j"]):
-                return TimeDelta(1*u.day)
+                return relativedelta(days=1)
             elif any(month in directoryPattern for month in ["%b", "%B", "%m"]):
-                return TimeDelta(31*u.day)
+                return relativedelta(months=1)
             elif any(year in directoryPattern for year in ["%Y", "%y"]):
-                return TimeDelta(365*u.day)
+                return relativedelta(years=1)
             else:
                 return None
         except Exception:
             raise
+
+    def _extract_files_meta(self, timerange, extractor, matcher=None):
+        """
+        Returns metadata information contained in URLs.
+
+        Parameters
+        ----------
+        timerange : `~sunpy.time.TimeRange`
+            Time interval where to find the directories for a given pattern.
+        extractor: `str`
+            Pattern to extract metadata by parsing the URL.
+        matcher: `dict`
+            Dictionary to check if extracted metadata is valid.
+
+        Returns
+        -------
+        `list` of `dict`
+            List of metadata info for all URLs.
+        """
+        self.extractor = extractor
+        urls = self.filelist(timerange)
+        metalist = []
+        for url in urls:
+            metadict = parse(extractor, url)
+            if metadict is not None:
+                append = True
+                metadict = metadict.named
+                metadict['url'] = url
+                if matcher is not None:
+                    for k in metadict:
+                        if k in matcher and str(metadict[k]) not in matcher[k]:
+                            append = False
+                            break
+                if append:
+                    metalist.append(metadict)
+        return metalist
+
+
+def get_timerange_from_exdict(exdict):
+    """
+    Function to get URL's timerange using extracted metadata.
+    It computes start and end times first using the given
+    dictionary and then returns a timerange.
+
+    Parameters
+    ----------
+    exdict : `dict`
+        Metadata extracted from the file's url.
+
+    Returns
+    -------
+    `~sunpy.time.TimeRange`
+        The time range of the file.
+    """
+    datetypes = ['year', 'month', 'day']
+    timetypes = ['hour', 'minute', 'second', 'millisecond']
+    dtlist = [int(exdict.get(d, 1)) for d in datetypes]
+    dtlist.extend([int(exdict.get(t, 0)) for t in timetypes])
+    startTime = Time(datetime(*dtlist))
+
+    tdelta = 1*u.millisecond
+    if "year" in exdict:
+        if calendar.isleap(int(exdict['year'])):
+            tdelta = 366*u.day
+        else:
+            tdelta = 365*u.day
+    if "month" in exdict:
+        days_in_month = calendar.monthrange(int(exdict['year']), int(exdict['month']))[1]
+        tdelta = days_in_month*u.day
+    if "day" in exdict:
+        tdelta = 1*u.day
+    if "hour" in exdict:
+        tdelta = 1*u.hour
+    if "minute" in exdict:
+        tdelta = 1*u.minute
+    if "second" in exdict:
+        tdelta = 1*u.second
+
+    endTime = startTime + TimeDelta(tdelta) - TimeDelta(1*u.millisecond)
+    file_timerange = TimeRange(startTime, endTime)
+    return file_timerange
